# `pptestszymonradosz` - My simple first project on PyPI

* Op1
* Op2
* Op3

# Install

```python
pip install pptestszymonradosz
```

### Usage
```python
from pptestszymonradosz.m_modpptest import name as n
>>> n("Name", "Surname")
Witaj: Name Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5]
```